#!/bin/sh

PERL=`which perl`
GDB=`which gdb`
DIR=`pwd`

if [ "$GDB" != "" ]; then
	echo "GDB path is"
	echo "	$GDB"
	echo "If you want to use an alternative GDB,"
	echo -n " write its path here (or just RETURN):"
else
	NO_GDB=1
	echo "We couldn't find GDB."
	echo -n " write its path here:"
fi
read UGDB
if [ "$UGDB" != "" ]; then
	GDB="$UGDB"
	echo "Now, GDB path is $UGDB."
elif [ "$NO_GDB" = "1" ]; then
	echo "We need GDB."
	exit
fi

echo ""

if [ "$PERL" != "" ]; then
	echo "PERL path is"
	echo "	$PERL"
	echo "If you want to use an alternative PERL,"
	echo -n " write its path here (or just RETURN):"
else
	NO_PERL=1
	echo "We couldn't find PERL."
	echo -n " write its path here:"
fi
read UPERL
if [ "$UPERL" != "" ]; then
	PERL="$UPERL"
	echo "Now, PERL path is $UPERL."
elif [ "$NO_PERL" = "1" ]; then
	echo "We need PERL."
	exit
fi

echo ""

echo "Install directory is"
echo "	${DIR}/mygcc"
echo "If you want to install another directory,"
echo -n "  write the path here (or just RETURN):"
read UDIR
if [ "$UDIR" = "" ]; then
	UDIR="${DIR}/mygcc"
	echo "Now, the install directory is $UDIR."
fi

echo ""
echo "	GDB:"
echo "		$GDB"
echo "	PERL:"
echo "		$PERL"
echo "	Install Dir.:"
echo "		$UDIR"
echo ""

echo "Press RETURN to start to build the system,"
echo "  Ctrl-C to abort it."

read

## Buid gcc-pg2

( \
cd gcc-2.95.2-obj; \
../gcc-2.95.2/configure --prefix="$UDIR" --enable-languages= ; \
make CFLAGS='-g' LIBCFLAGS='-g' LIBCXXFLAGS='-g' CXXFLAGS='-g' BOOT_CFLAGS='-g' MYCFLAGS='-g -Wpointer-arith -Wnested-externs' MYCXXFLAGS='-g -Wpointer-arith -Wnested-externs -Woverloaded-virtual -Wbad-function-cast -Winline -Wwrite-strings -pedantic -Wno-long-long' OPTIMIZE='-O0' bootstrap ; \
make install \
)

## timestamp.o -> libpg2.a

UNAME=`grep -v ^# gcc-2.95.2-obj/config.status | "$PERL" -e 'while(<>){if(/--host=([^ ]+)/){print $1;}}'`

( \
cd gcc-2.95.2; \
"$UDIR"/bin/gcc -g timestamp.c -c; \
mv timestamp.o "$UDIR"/lib/gcc-lib/"$UNAME"/2.95.2/libpg2.a \
)

## Make perl-mods

PMODS="$UDIR"/perl-mods

for i in IO-Stty-.02 IO-Tty-0.03 Expect.pm-1.07 ;
do
	( \
	cd $i; "$PERL" Makefile.PL; mv Makefile Makefile.bak; \
	"$PERL" ../subst.pl "$PMODS"; \
	make; make install \
	)
done

## Make gdb-wrapper.pl

echo ""
echo "Making gdb-wrapper.pl"

SITEPERL=`grep ^INSTALLSITELIB IO-Stty-.02/Makefile | awk 'BEGIN{FS=")"} {print $2}'`

"$PERL" mkwrapper.pl "$PERL" "$PMODS""$SITEPERL" "$GDB"
chmod 755 gdb-wrapper.pl

echo ""
echo "Done."
echo ""
